==> tomee-project-8.0.13-source-release.zip: tomee-project-8.0.13/container/openejb-core/src/main/java/org/apache/openejb/config/rules/CheckCdiEnabled.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openejb.config.rules;

import org.apache.openejb.config.EjbModule;
import org.apache.xbean.finder.IAnnotationFinder;

import javax.inject.Inject;

public class CheckCdiEnabled extends ValidationBase {
    public void validate(final EjbModule ejbModule) {
        if (ejbModule.getFinder() == null || ejbModule.getProperties().containsKey("openejb.cdi.activated")) {
            return;
        }

        if (ejbModule.getBeans() == null
            && hasAtInject(ejbModule.getFinder())) {
            warn(ejbModule.getModuleId(), "cdi.notEnabled", ejbModule.getModuleId());
        }
    }

    private static boolean hasAtInject(final IAnnotationFinder finder) {
        return !finder.findAnnotatedMethods(Inject.class).isEmpty()
            || !finder.findAnnotatedFields(Inject.class).isEmpty();
    }
}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/container/openejb-core/src/main/java/org/apache/openejb/config/rules/CheckCdiEnabled.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openejb.config.rules;

import org.apache.openejb.config.EjbModule;
import org.apache.xbean.finder.IAnnotationFinder;

import jakarta.inject.Inject;

public class CheckCdiEnabled extends ValidationBase {
    public void validate(final EjbModule ejbModule) {
        if (ejbModule.getFinder() == null || ejbModule.getProperties().containsKey("openejb.cdi.activated")) {
            return;
        }

        if (ejbModule.getBeans() == null
            && hasAtInject(ejbModule.getFinder())) {
            warn(ejbModule.getModuleId(), "cdi.notEnabled", ejbModule.getModuleId());
        }
    }

    private static boolean hasAtInject(final IAnnotationFinder finder) {
        return !finder.findAnnotatedMethods(Inject.class).isEmpty()
            || !finder.findAnnotatedFields(Inject.class).isEmpty();
    }
}
